==> haskell-random-source-0.3.0.11-131-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-random-source.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 random-source
version:              0.3.0.11
visibility:           public
id:                   random-source-0.3.0.11-EPSiJZy7F6xH4n4E7T7EpL
key:                  random-source-0.3.0.11-EPSiJZy7F6xH4n4E7T7EpL
license:              LicenseRef-PublicDomain
maintainer:           James Cook <mokus@deepbondi.net>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/mokus0/random-fu
synopsis:             Generic basis for random number generators
description:
    Random number generation based on entropy sources
    able to produce a small but well-defined set of
    primitive variates.  Also includes facilities for
    \"completing\" partial implementations, making it
    easy to define new entropy sources in a way that
    is naturally forward-compatible.

category:             Math
abi:                  4e5852889176e6b0b034cca9668a0672
exposed:              True
exposed-modules:
    Data.Random.Internal.Source Data.Random.Internal.Words
    Data.Random.Source Data.Random.Source.DevRandom
    Data.Random.Source.IO Data.Random.Source.MWC
    Data.Random.Source.PureMT Data.Random.Source.Std
    Data.Random.Source.StdGen

hidden-modules:
    Data.Random.Source.Internal.Prim Data.Random.Source.Internal.TH

import-dirs:          /usr/lib/ghc-9.0.2/site-local/random-source-0.3.0.11
library-dirs:         /usr/lib/ghc-9.0.2/site-local/random-source-0.3.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-random-source
hs-libraries:         HSrandom-source-0.3.0.11-EPSiJZy7F6xH4n4E7T7EpL
depends:
    base-4.15.1.0 flexible-defaults-0.0.3-84yaVfLui8l40IIMsezaao
    mersenne-random-pure64-0.2.2.0-JBfa5Udtdu2F92xl8id93X mtl-2.2.2
    mwc-random-0.15.0.2-1clukEUvS6oHltYG951RK
    primitive-0.7.4.0-ApwAailRBWz8tJqPYVRiUV
    random-1.2.1.1-7qFLeSti7cd2nEeY08jtlf
    stateref-0.3-9u9QCRlvo9dHk1YF6aLbH9
    syb-0.7.2.1-84p4GY15bjq39xuR6nm671 template-haskell-2.17.0.0
    th-extras-0.0.0.6-24KmJzlOdELJxt7HvLXhUU

haddock-interfaces:
    /usr/share/doc/haskell-random-source/html/random-source.haddock

haddock-html:         /usr/share/doc/haskell-random-source/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-random-source-0.3.0.11-132-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-random-source.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 random-source
version:              0.3.0.11
visibility:           public
id:                   random-source-0.3.0.11-7JfwqsRb9sM8c3aXNwFHXR
key:                  random-source-0.3.0.11-7JfwqsRb9sM8c3aXNwFHXR
license:              LicenseRef-PublicDomain
maintainer:           James Cook <mokus@deepbondi.net>
author:               James Cook <mokus@deepbondi.net>
stability:            provisional
homepage:             https://github.com/mokus0/random-fu
synopsis:             Generic basis for random number generators
description:
    Random number generation based on entropy sources
    able to produce a small but well-defined set of
    primitive variates.  Also includes facilities for
    \"completing\" partial implementations, making it
    easy to define new entropy sources in a way that
    is naturally forward-compatible.

category:             Math
abi:                  8bd55b647af3e44dbf5fb3e41d453fec
exposed:              True
exposed-modules:
    Data.Random.Internal.Source Data.Random.Internal.Words
    Data.Random.Source Data.Random.Source.DevRandom
    Data.Random.Source.IO Data.Random.Source.MWC
    Data.Random.Source.PureMT Data.Random.Source.Std
    Data.Random.Source.StdGen

hidden-modules:
    Data.Random.Source.Internal.Prim Data.Random.Source.Internal.TH

import-dirs:          /usr/lib/ghc-9.0.2/site-local/random-source-0.3.0.11
library-dirs:         /usr/lib/ghc-9.0.2/site-local/random-source-0.3.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-random-source
hs-libraries:         HSrandom-source-0.3.0.11-7JfwqsRb9sM8c3aXNwFHXR
depends:
    base-4.15.1.0 flexible-defaults-0.0.3-BslZdCvFWdaCyM5ZM8dukP
    mersenne-random-pure64-0.2.2.0-3CPJaKyOCJlBG9H8TQR5gl mtl-2.2.2
    mwc-random-0.15.0.2-GFrU2EVLODTGL2MjxNowgU
    primitive-0.7.4.0-5JlbNIYTeCwFwdVF07wEKE
    random-1.2.1.1-8S22Zn7bY7e7hGShjNjXlP
    stateref-0.3-9u9QCRlvo9dHk1YF6aLbH9
    syb-0.7.2.1-9qjN5XOwl6U4K3t2Rmrb6z template-haskell-2.17.0.0
    th-extras-0.0.0.6-DOpgT6SSLnSLjQ0drJh6yT

haddock-interfaces:
    /usr/share/doc/haskell-random-source/html/random-source.haddock

haddock-html:         /usr/share/doc/haskell-random-source/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
